==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/DeploymentConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.DeploymentConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Deployment Configuration
 * @property scaleUnits Scale units will contains list of deployment data
 * @property version deployment template version
 */
public data class DeploymentConfigurationArgs(
    public val scaleUnits: Output<List<ScaleUnitsArgs>>,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.DeploymentConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.azurestackhci.inputs.DeploymentConfigurationArgs =
        com.pulumi.azurenative.azurestackhci.inputs.DeploymentConfigurationArgs.builder()
            .scaleUnits(
                scaleUnits.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DeploymentConfigurationArgs].
 */
@PulumiTagMarker
public class DeploymentConfigurationArgsBuilder internal constructor() {
    private var scaleUnits: Output<List<ScaleUnitsArgs>>? = null

    private var version: Output<String>? = null

    /**
     * @param value Scale units will contains list of deployment data
     */
    @JvmName("rmdtenriurmghqtq")
    public suspend fun scaleUnits(`value`: Output<List<ScaleUnitsArgs>>) {
        this.scaleUnits = value
    }

    @JvmName("ohchbkrykcmilqdm")
    public suspend fun scaleUnits(vararg values: Output<ScaleUnitsArgs>) {
        this.scaleUnits = Output.all(values.asList())
    }

    /**
     * @param values Scale units will contains list of deployment data
     */
    @JvmName("gotgyeyfryyayobf")
    public suspend fun scaleUnits(values: List<Output<ScaleUnitsArgs>>) {
        this.scaleUnits = Output.all(values)
    }

    /**
     * @param value deployment template version
     */
    @JvmName("ixxomwjikxspdfrw")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value Scale units will contains list of deployment data
     */
    @JvmName("qstjpcatjgbqkggg")
    public suspend fun scaleUnits(`value`: List<ScaleUnitsArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scaleUnits = mapped
    }

    /**
     * @param argument Scale units will contains list of deployment data
     */
    @JvmName("oqfbwwfutoenihst")
    public suspend fun scaleUnits(argument: List<suspend ScaleUnitsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ScaleUnitsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.scaleUnits = mapped
    }

    /**
     * @param argument Scale units will contains list of deployment data
     */
    @JvmName("fnslygpeclflyxcb")
    public suspend fun scaleUnits(vararg argument: suspend ScaleUnitsArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ScaleUnitsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.scaleUnits = mapped
    }

    /**
     * @param argument Scale units will contains list of deployment data
     */
    @JvmName("ixqjwtaanmmythnp")
    public suspend fun scaleUnits(argument: suspend ScaleUnitsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScaleUnitsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.scaleUnits = mapped
    }

    /**
     * @param values Scale units will contains list of deployment data
     */
    @JvmName("kbphlhtyjhjuapwd")
    public suspend fun scaleUnits(vararg values: ScaleUnitsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scaleUnits = mapped
    }

    /**
     * @param value deployment template version
     */
    @JvmName("eusiwlvsqoviwhju")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): DeploymentConfigurationArgs = DeploymentConfigurationArgs(
        scaleUnits = scaleUnits ?: throw PulumiNullFieldException("scaleUnits"),
        version = version,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/DeploymentConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.DeploymentConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Deployment Configuration
 * @property scaleUnits Scale units will contains list of deployment data
 * @property version deployment template version
 */
public data class DeploymentConfigurationArgs(
    public val scaleUnits: Output<List<ScaleUnitsArgs>>,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.DeploymentConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.azurestackhci.inputs.DeploymentConfigurationArgs =
        com.pulumi.azurenative.azurestackhci.inputs.DeploymentConfigurationArgs.builder()
            .scaleUnits(
                scaleUnits.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DeploymentConfigurationArgs].
 */
@PulumiTagMarker
public class DeploymentConfigurationArgsBuilder internal constructor() {
    private var scaleUnits: Output<List<ScaleUnitsArgs>>? = null

    private var version: Output<String>? = null

    /**
     * @param value Scale units will contains list of deployment data
     */
    @JvmName("fmqbvqgsrfnpngmo")
    public suspend fun scaleUnits(`value`: Output<List<ScaleUnitsArgs>>) {
        this.scaleUnits = value
    }

    @JvmName("enpyyknklnmfasth")
    public suspend fun scaleUnits(vararg values: Output<ScaleUnitsArgs>) {
        this.scaleUnits = Output.all(values.asList())
    }

    /**
     * @param values Scale units will contains list of deployment data
     */
    @JvmName("xrfqjkvxrdsufokc")
    public suspend fun scaleUnits(values: List<Output<ScaleUnitsArgs>>) {
        this.scaleUnits = Output.all(values)
    }

    /**
     * @param value deployment template version
     */
    @JvmName("kobgnynkdffdjfpy")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value Scale units will contains list of deployment data
     */
    @JvmName("xskbhtryuxxjthrl")
    public suspend fun scaleUnits(`value`: List<ScaleUnitsArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scaleUnits = mapped
    }

    /**
     * @param argument Scale units will contains list of deployment data
     */
    @JvmName("hjnhgtflqtihvtfd")
    public suspend fun scaleUnits(argument: List<suspend ScaleUnitsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ScaleUnitsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.scaleUnits = mapped
    }

    /**
     * @param argument Scale units will contains list of deployment data
     */
    @JvmName("wswrssbqbbfayswm")
    public suspend fun scaleUnits(vararg argument: suspend ScaleUnitsArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ScaleUnitsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.scaleUnits = mapped
    }

    /**
     * @param argument Scale units will contains list of deployment data
     */
    @JvmName("nhxketeytphjscmg")
    public suspend fun scaleUnits(argument: suspend ScaleUnitsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScaleUnitsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.scaleUnits = mapped
    }

    /**
     * @param values Scale units will contains list of deployment data
     */
    @JvmName("yveyupjleguwmvsd")
    public suspend fun scaleUnits(vararg values: ScaleUnitsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scaleUnits = mapped
    }

    /**
     * @param value deployment template version
     */
    @JvmName("kijutmvgvedvwgwu")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): DeploymentConfigurationArgs = DeploymentConfigurationArgs(
        scaleUnits = scaleUnits ?: throw PulumiNullFieldException("scaleUnits"),
        version = version,
    )
}
